summaryrefslogtreecommitdiffstats
path: root/tdeui/knumvalidator.h
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2013-03-02 15:57:34 -0600
committerDarrell Anderson <humanreadable@yahoo.com>2013-03-02 15:57:34 -0600
commit7c0b0c9dc9fcbe9c198925bdc7ee18ac6be49f4f (patch)
treec76702a7f6310fbe9d437e347535422e836e94e9 /tdeui/knumvalidator.h
parenta2a38be7600e2a2c2b49c66902d912ca036a2c0f (diff)
parent27bbee9a5f9dcda53d8eb23863ee670ad1360e41 (diff)
downloadtdelibs-7c0b0c9dc9fcbe9c198925bdc7ee18ac6be49f4f.tar.gz
tdelibs-7c0b0c9dc9fcbe9c198925bdc7ee18ac6be49f4f.zip
Merge branch 'master' of http://scm.trinitydesktop.org/scm/git/tdelibs
Diffstat (limited to 'tdeui/knumvalidator.h')
-rw-r--r--tdeui/knumvalidator.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/tdeui/knumvalidator.h b/tdeui/knumvalidator.h
index 8fa2ea76e..5c7b31484 100644
--- a/tdeui/knumvalidator.h
+++ b/tdeui/knumvalidator.h
@@ -147,7 +147,7 @@ class TDEUI_EXPORT KFloatValidator : public TQValidator {
virtual double top () const;
/**
* Sets the validator to be locale aware if @p is true. In this case, the
* character KLocale::decimalSymbol() from the global locale is recognized
* as decimal separator.
*/
void setAcceptLocalizedNumbers(bool b);
@@ -169,8 +169,8 @@ class TDEUI_EXPORT KFloatValidator : public TQValidator {
KDoubleValidator extends TQDoubleValidator to be
locale-aware. That means that - subject to not being disabled -
- KLocale::decimalSymbol(), KLocale::thousandsSeparator()
- and KLocale::positiveSign() and KLocale::negativeSign()
+ TDELocale::decimalSymbol(), TDELocale::thousandsSeparator()
+ and TDELocale::positiveSign() and TDELocale::negativeSign()
are respected.
@author Marc Mutz <mutz@kde.org>
@@ -147,7 +147,7 @@ class TDEUI_EXPORT KFloatValidator : public TQValidator {
/**
* Sets the validator to be locale aware if @p is true. In this case, the
- * character KLocale::decimalSymbol() from the global locale is recognized
+ * character TDELocale::decimalSymbol() from the global locale is recognized
* as decimal separator.
*/